/*
 * ADDTHEME.CMD
 * version 1.0 (C) Alex Taylor, 2001
 *
 * Script to add a theme to the eComStation Theme Manager. 
 * Run from the thememgr directory.
 * 
 */
CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
CALL SysLoadFuncs

PARSE ARG name

SAY "ADDTHEME - Add a window control theme to the eComStation Theme Manager."

IF name == '' THEN DO
    SAY "Usage:"
    SAY
    SAY "   ADDTHEME name"
    SAY
    SAY "where 'name' is the name of the theme to be added."
    EXIT
END

IF FindFiles( name ) \= 1 THEN DO
    CALL MissingFile( name )
    EXIT
END

spec = SysSearchPath('PATH', 'RESMGR.CMD')
IF spec = "" THEN DO
    SAY
    SAY "Cannot locate the RESMGR program.  Martin Lafaix's RESMGR package must be"
    SAY "installed and on the system path in order to use this script."
    SAY
    EXIT
END

spec = SysSearchPath( Directory(), 'PMMRGRES.DLL')
IF spec = "" THEN DO
    SAY
    SAY "PMMRGRES.DLL not found.  A copy of PMMRGRES.DLL must exist in the current"
    SAY "directory.  Copy this file from your \OS2\DLL system directory, and try"
    SAY "again."
    SAY
    EXIT
END

CALL GenerateDLL( name )
CALL AddIndex( name )
SAY "Finished."
SAY

EXIT



FindFiles: PROCEDURE
    ARG theme
    idxfile = theme".IDX"
    resfile = theme".RES"
    bmpfile = theme".BMP"
    gotfiles = 1
    spec = SysSearchPath( DIRECTORY(), idxfile )
    if spec == "" THEN gotfiles = 0
    spec = SysSearchPath( DIRECTORY(), resfile )
    if spec == "" THEN gotfiles = 0
    spec = SysSearchPath( DIRECTORY(), bmpfile )
    if spec == "" THEN gotfiles = 0
RETURN gotfiles


MissingFile: PROCEDURE
    ARG theme
    SAY
    SAY "Cannot locate at least one required file for theme '"theme"'."
    SAY "The following files must exist in the current directory:"
    SAY "   " theme".IDX"
    SAY "   " theme".RES"
    SAY "   " theme".BMP"
    SAY
RETURN


GenerateDLL: PROCEDURE
    ARG theme
    resfile = theme".RES"
    dllname = theme".DLL"
    SAY
    SAY "Adding theme" theme"..."
    "COPY PMMRGRES.dll" dllname
    CALL RESMGR "-a" dllname resfile
RETURN 


AddIndex:
    ARG theme
    idxfile = theme".IDX"
    newidx = LINEIN( idxfile, 1, 1 )
    rc = LINEOUT('thememgr.idx', newidx )
    if rc == 0 THEN SAY "Theme index updated successfully."
RETURN

